package com.muyu.web.controller;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.muyu.web.common.Result;
import com.muyu.web.domain.MessageTemplate;
import com.muyu.web.domain.MessageTemplateValue;
import com.muyu.web.domain.req.MessageTemplateSaveReq;
import com.muyu.web.domain.req.MessageTemplateValueSaveReq;
import com.muyu.web.service.MessageService;
import com.muyu.web.service.MessageTemplateService;
import com.muyu.web.service.MessageTemplateValueService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * @Author: DongZeLiang
 * @date: 2024/9/18
 * @Description: 报文控制层
 * @Version: 1.0
 */
@RestController
@RequestMapping("/message")
public class MessageController {

    @Autowired
    private MessageService messageService;

    @Autowired
    private MessageTemplateService messageTemplateService;

    @Autowired
    private MessageTemplateValueService messageTemplateValueService;

    /**
     * 报文模板列表
     * @return 列表
     */
    @GetMapping("/template/list")
    public Result<List<MessageTemplate>> templateList(){
        return Result.success(
                messageTemplateService.list()
        );
    }

    /**
     * 保存报文模板
     * @return 统一返回值
     */
    @PostMapping("/template")
    public Result<String> save(@RequestBody @Validated MessageTemplateSaveReq messageTemplateSaveReq){
        messageService.saveMessageTemplate(messageTemplateSaveReq);
        return Result.success();
    }

    /**
     * 报文模板值列表
     * @return 统一返回值
     */
    @GetMapping("/template/{messageTemplateId}/value")
    public Result<List<MessageTemplateValue>> templateValueList(@PathVariable("messageTemplateId") Long messageTemplateId) {
        return Result.success(
                this.messageTemplateValueService.list(
                        new LambdaQueryWrapper<>(){{
                            eq(MessageTemplateValue::getMessageId, messageTemplateId);
                        }}
                )
        );
    }
    /**
     * 保存报文模板
     * @return 统一返回值
     */
    @PostMapping("/template/{messageTemplateId}/value")
    public Result<String> templateValueSave(
            @RequestBody @Validated MessageTemplateValueSaveReq messageTemplateValueSaveReq,
            @PathVariable("messageTemplateId") Long messageTemplateId
    ){
        messageTemplateValueService.save(
                MessageTemplateValue.builder()
                        .messageId(messageTemplateId)
                        .code(messageTemplateValueSaveReq.getCode())
                        .category(messageTemplateValueSaveReq.getCategory())
                        .label(messageTemplateValueSaveReq.getLabel())
                        .length(messageTemplateValueSaveReq.getLength())
                        .maxValue(messageTemplateValueSaveReq.getMaxValue())
                        .minValue(messageTemplateValueSaveReq.getMinValue())
                        .valueType(messageTemplateValueSaveReq.getValueType())
                        .elValue(messageTemplateValueSaveReq.getElValue())
                        .fixedValue(messageTemplateValueSaveReq.getFixedValue())
                        .startLocation(messageTemplateValueSaveReq.getStartLocation())
                        .endLocation(messageTemplateValueSaveReq.getEndLocation())
                        .build()
        );
        return Result.success();
    }



}
