package com.muyu.web.service.impl;

import com.muyu.system.enums.MessageTemplateValueType;
import com.muyu.web.domain.MessageTemplate;
import com.muyu.web.domain.MessageTemplateValue;
import com.muyu.web.domain.req.MessageTemplateSaveReq;
import com.muyu.web.service.MessageService;
import com.muyu.web.service.MessageTemplateService;
import com.muyu.web.service.MessageTemplateValueService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;

/**
 * @Author: DongZeLiang
 * @date: 2024/9/20
 * @Description: 报文业务实现层
 * @Version: 1.0
 */
@Service
public class MessageServiceImpl implements MessageService {

    @Autowired
    private MessageTemplateService messageTemplateService;

    @Autowired
    private MessageTemplateValueService messageTemplateValueService;

    /**
     * 保存报文模板
     *
     * @param messageTemplateSaveReq 报文模板保存请求对象
     */
    @Override
    public void saveMessageTemplate (MessageTemplateSaveReq messageTemplateSaveReq) {
        MessageTemplate messageTemplate = MessageTemplate.builder().messageName(messageTemplateSaveReq.getMessageName()).description(messageTemplateSaveReq.getDescription()).build();
        messageTemplateService.save(messageTemplate);
        messageTemplateValueService.saveBatch(new ArrayList<>() {{
            add(MessageTemplateValue.builder().messageId(messageTemplate.getId()).code("vin").label("VIN").category("base").length(17).startLocation(1).endLocation(17).valueType(MessageTemplateValueType.EL.code()).elValue("this.vin").build());
            add(MessageTemplateValue.builder().messageId(messageTemplate.getId()).code("timeMillis").label("报文采集毫秒").category("base").length(13).startLocation(18).endLocation(30).valueType(MessageTemplateValueType.EL.code()).elValue("this.timeMillis").build());
        }});
    }
}
